@@ -1,8 +1,6 @@
-# TODO: Test graphs
 df <- data.frame(
   Group = "X",
-  P1 = "2AB(US)",
-  R1 = TRUE
+  P1 = "2AB>(US)"
 )
 df <- parse_design(df)
 models <- supported_models()
@@ -13,7 +11,7 @@ test_that("calmr_model_graph works", {
     model = models[1],
     parameters = get_parameters(design = df, model = models[1])
   )
-  g <- calmr_model_graph(results(res)$vs)
+  g <- calmr_model_graph(results(res)$associations)
   expect_named(g)
 })
 
@@ -23,21 +21,27 @@ res <- run_experiment(
   parameters = get_parameters(design = df, model = models[1])
 )
 test_that("calmr_model_graph takes a trial", {
-  g <- calmr_model_graph(results(res)$vs, t = 1)
+  g <- calmr_model_graph(results(res)$associations, t = 1)
   expect_named(g)
 })
 
 test_that("calmr_model_graph throws a warning if trial exceeds data", {
-  expect_warning(calmr_model_graph(results(res)$vs, t = 5000))
+  expect_warning(calmr_model_graph(results(res)$associations, t = 5000))
 })
 
 # Test graphs for every model
 for (m in models) {
   test_that(sprintf("graphs for model %s", m), {
+    if (m %in% supported_timed_models()) {
+      tims <- get_timings(df, model = m)
+    } else {
+      tims <- NULL
+    }
     res <- run_experiment(
       df,
       model = m,
-      parameters = get_parameters(design = df, model = m)
+      parameters = get_parameters(design = df, model = m),
+      timings = tims
     )
     g <- graph(res)
     expect_named(g)
