@@ -1,9 +1,7 @@
 df <- data.frame(
   Group = c("A", "B"),
-  P1 = c("2A>(US)", "2B>(US)"),
-  R1 = c(TRUE, TRUE),
-  P2 = c("2AX>(US)", "2AX>(US)"),
-  R2 = c(TRUE, TRUE)
+  P1 = c("!2A>(US)", "!2B>(US)"),
+  P2 = c("!2AX>(US)", "!2AX>(US)")
 )
 df <- parse_design(df)
 supported_mods <- supported_models()
@@ -14,8 +12,17 @@ test_that("get_model fails if model is not supported", {
 
 for (m in supported_mods) {
   test_that(paste("model", m, "works"), {
+    if (m %in% supported_timed_models()) {
+      tims <- get_timings(df, model = m)
+    } else {
+      tims <- NULL
+    }
     pars <- get_parameters(df, model = m)
-    args <- make_experiment(df, parameters = pars, model = m)
+    args <- make_experiment(df,
+      parameters = pars,
+      timings = tims,
+      model = m
+    )
     res <- run_experiment(args)
     expect_named(res@results@aggregated_results)
   })
